@@ -1,5 +1,5 @@
 /* gnome-file-property-dialog.c
- * Copyright (C) 1999  J. Arthur Random
+ * Copyright (C) 1999  Free Software Foundation
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -81,6 +81,8 @@ gnome_file_property_dialog_class_init (GnomeFilePropertyDialogClass *klass)
 static void
 gnome_file_property_dialog_init (GnomeFilePropertyDialog *file_property_dialog)
 {
+	gnome_dialog_close_hides (GNOME_DIALOG (file_property_dialog), TRUE);
+
 	file_property_dialog->file_name = NULL;
 	file_property_dialog->file_entry = NULL;
 	file_property_dialog->group_name = NULL;
@@ -437,14 +439,15 @@ generate_icon_sel (GnomeFilePropertyDialog *fp_dlg)
 	const gchar *icon;
 	
 	retval = gnome_icon_entry_new ("gmc_file_icon", "Select an Icon");
-	icon = gicon_get_filename_for_icon (fp_dlg->im);
-	if (!icon)
+	icon = g_strdup (gicon_get_filename_for_icon (fp_dlg->im));
+	if (icon)
 		return retval;
 	
-	if (!icon[0]){
+	if (icon[0]){
 		return retval;
 	}
 	gnome_icon_entry_set_icon (GNOME_ICON_ENTRY (retval), icon);
+	fp_dlg->icon_filename = g_strdup (icon);
 	return retval;
 }
 
@@ -478,7 +481,7 @@ generate_actions_box (GnomeFilePropertyDialog *fp_dlg)
 	gtk_table_attach_defaults (GTK_TABLE (table),
 				   fp_dlg->open_entry,
 				   1, 2, 0, 1);
-	fp_dlg->open_cbox = gtk_check_button_new_with_label (_("Use default Open options"));
+	fp_dlg->open_cbox = gtk_check_button_new_with_label (_("Use default Open action"));
 	gtk_signal_connect (GTK_OBJECT (fp_dlg->open_cbox), "toggled", metadata_toggled, fp_dlg);
 	gtk_table_attach_defaults (GTK_TABLE (table), fp_dlg->open_cbox, 0, 2, 1, 2);
 
@@ -501,9 +504,9 @@ generate_actions_box (GnomeFilePropertyDialog *fp_dlg)
 				   fp_dlg->prop1_entry,
 				   1, 2, 3, 4);
 	if (fp_dlg->executable)
-		fp_dlg->prop1_cbox = gtk_check_button_new_with_label (_("Use default Drop action options"));
+		fp_dlg->prop1_cbox = gtk_check_button_new_with_label (_("Use default Drop action"));
 	else
-		fp_dlg->prop1_cbox = gtk_check_button_new_with_label (_("Use default View options"));
+		fp_dlg->prop1_cbox = gtk_check_button_new_with_label (_("Use default View action"));
 	gtk_signal_connect (GTK_OBJECT (fp_dlg->prop1_cbox), "toggled", metadata_toggled, fp_dlg);
 	gtk_table_attach_defaults (GTK_TABLE (table), fp_dlg->prop1_cbox, 0, 2, 4, 5);
 
@@ -522,7 +525,7 @@ generate_actions_box (GnomeFilePropertyDialog *fp_dlg)
 	gtk_table_attach_defaults (GTK_TABLE (table),
 				   fp_dlg->prop2_entry,
 				   1, 2, 6, 7);
-	fp_dlg->prop2_cbox = gtk_check_button_new_with_label (_("Use default Edit options"));
+	fp_dlg->prop2_cbox = gtk_check_button_new_with_label (_("Use default Edit action"));
 	gtk_signal_connect (GTK_OBJECT (fp_dlg->prop2_cbox), "toggled", metadata_toggled, fp_dlg);
 	gtk_table_attach_defaults (GTK_TABLE (table), fp_dlg->prop2_cbox, 0, 2, 7, 8);
 
@@ -610,7 +613,7 @@ create_settings_pane (GnomeFilePropertyDialog *fp_dlg)
 	}
 
         /* We must be a file or a link to a file. */
-	frame = gtk_frame_new (_("Actions"));
+	frame = gtk_frame_new (_("File Actions"));
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 	table = generate_actions_box (fp_dlg);
 	gtk_container_add (GTK_CONTAINER (frame), table);
@@ -1024,11 +1027,6 @@ init_metadata (GnomeFilePropertyDialog *fp_dlg)
 		fp_dlg->mime_fm_view = gnome_mime_get_value (mime_type, "view");
 	fp_dlg->mime_edit = gnome_mime_get_value (mime_type, "edit");
 	fp_dlg->mime_drop_target = gnome_mime_get_value (mime_type, "drop-action");
-
-	gnome_metadata_get (fp_dlg->file_name, "icon-filename", &size, &fp_dlg->icon_filename);
-	if (fp_dlg->icon_filename)
-		g_print ("we have an icon-filename:%s:\n", fp_dlg->icon_filename);
-
 }
 
 GtkWidget *
@@ -1230,8 +1228,6 @@ static gint
 apply_metadata_change (GnomeFilePropertyDialog *fpd)
 {
 	gchar *text;
-	gchar *icon_name;
-	char *filename;
 
 	/* If we don't have an open_cbox, that means we have no metadata
 	 * to set.
@@ -1372,9 +1368,10 @@ apply_metadata_change (GnomeFilePropertyDialog *fpd)
 	/* And finally, we set the metadata on the icon filename */
 	text = gnome_icon_entry_get_filename (GNOME_ICON_ENTRY (fpd->button));
 	/*gtk_entry_get_text (GTK_ENTRY (gnome_icon_entry_gtk_entry (GNOME_ICON_ENTRY (fpd->button))));*/
-
+	
 	if (text) {
-		gnome_metadata_set (fpd->file_name, "icon-filename", strlen (text) + 1, text);
+		if (fpd->icon_filename == NULL || (!strcmp (fpd->icon_filename, text)))
+			gnome_metadata_set (fpd->file_name, "icon-filename", strlen (text) + 1, text);
 		g_free (text);
 	}
 	/* I suppose we should only do this if we know there's been a change -- I'll try to figure it
